@@ -1,8 +1,8 @@
 package Coro::ProcessPool::Process;
-# ABSTRACT Manager for worker subprocess
-$Coro::ProcessPool::Process::VERSION = '0.26_004'; # TRIAL
+# ABSTRACT: Manager for worker subprocess
+$Coro::ProcessPool::Process::VERSION = '0.26_005'; # TRIAL
 
-$Coro::ProcessPool::Process::VERSION = '0.26004';use strict;
+$Coro::ProcessPool::Process::VERSION = '0.26005';use strict;
 use warnings;
 use Carp;
 use Coro;
@@ -152,11 +152,11 @@ __END__
 
 =head1 NAME
 
-Coro::ProcessPool::Process
+Coro::ProcessPool::Process - Manager for worker subprocess
 
 =head1 VERSION
 
-version 0.26_004
+version 0.26_005
 
 =head1 AUTHOR
 
