@@ -1,8 +1,8 @@
 package Coro::ProcessPool::Worker;
-# ABSTRACT Run loop for worker process
-$Coro::ProcessPool::Worker::VERSION = '0.26_004'; # TRIAL
+# ABSTRACT: Run loop for worker process
+$Coro::ProcessPool::Worker::VERSION = '0.26_005'; # TRIAL
 
-$Coro::ProcessPool::Worker::VERSION = '0.26004';use strict;
+$Coro::ProcessPool::Worker::VERSION = '0.26005';use strict;
 use warnings;
 use Coro;
 use Coro::Countdown;
@@ -81,11 +81,11 @@ __END__
 
 =head1 NAME
 
-Coro::ProcessPool::Worker
+Coro::ProcessPool::Worker - Run loop for worker process
 
 =head1 VERSION
 
-version 0.26_004
+version 0.26_005
 
 =head1 AUTHOR
 
